@@ -56,7 +56,7 @@ from typing_extensions import Literal
 # this package
 from domdf_python_tools.compat import importlib_metadata
 
-__all__ = ["discover"]
+__all__ = ["discover", "discover_entry_points"]
 
 
 @overload
@@ -96,7 +96,7 @@ def discover(
 	.. versionchanged:: 1.0.0
 
 		Added the ``exclude_side_effects`` parameter.
-	"""
+	"""  # noqa D400
 
 	matching_objects = []
 
@@ -107,7 +107,7 @@ def discover(
 		package.__path__,  # type: ignore
 		prefix=package.__name__ + '.',
 		):
-		module = __import__(module_name, fromlist=['__trash'], level=0)
+		module = __import__(module_name, fromlist=["__trash"], level=0)
 
 		# Check all the functions in that module
 		for _, imported_objects in inspect.getmembers(module, match_func):
@@ -143,11 +143,11 @@ def discover_entry_points(
 		match_func: Optional[Callable[[Any], bool]] = None,
 		) -> List[Any]:
 	"""
-	Returns a list of entry points in the given category,
-	optionally filtered by ``match_func``.
+	Returns a list of entry points in the given category, optionally filtered by ``match_func``.
 
 	:param group_name: The entry point group name, e.g. ``'entry_points'``.
-	:param match_func: Function taking an object and returning :py:obj:`True` if the object is to be included in the output.
+	:param match_func: Function taking an object and returning :py:obj:`True`
+		if the object is to be included in the output.
 	:default match_func: :py:obj:`None`, which includes all objects.
 
 	:return: List of matching objects.
