@@ -15,7 +15,7 @@ Functions for paths and files.
 #  Parts of the docstrings and the PathPlus class based on the Python 3.8.2 Documentation
 #  Licensed under the Python Software Foundation License Version 2.
 #  Copyright © 2001-2020 Python Software Foundation. All rights reserved.
-#  Copyright © 2000 BeOpen.com . All rights reserved.
+#  Copyright © 2000 BeOpen.com. All rights reserved.
 #  Copyright © 1995-2000 Corporation for National Research Initiatives. All rights reserved.
 #  Copyright © 1991-1995 Stichting Mathematisch Centrum. All rights reserved.
 #
@@ -68,12 +68,16 @@ __all__ = [
 		"WindowsPathPlus",
 		"in_directory",
 		"_P",
+		"traverse_to_file",
 		]
 
 newline_default = object()
-_P = TypeVar("_P", bound=pathlib.PurePath)
+
+_P = TypeVar("_P", bound=pathlib.Path)
 """
 .. versionadded:: 0.11.0
+
+.. versionchanged:: 1.7.0  Now bound to :class:`pathlib.Path`.
 """
 
 
@@ -149,7 +153,7 @@ def delete(filename: PathLike, **kwargs):
 	os.remove(os.path.join(os.getcwd(), filename), **kwargs)
 
 
-def maybe_make(directory: PathLike, mode: int = 0o777, parents: bool = False, exist_ok: bool = False):
+def maybe_make(directory: PathLike, mode: int = 0o777, parents: bool = False):
 	"""
 	Create a directory at the given path, but only if the directory does not already exist.
 
@@ -164,18 +168,18 @@ def maybe_make(directory: PathLike, mode: int = 0o777, parents: bool = False, ex
 		If :py:obj:`True`, any missing parents of this path are created as needed; they are created with the
 		default permissions without taking mode into account (mimicking the POSIX mkdir -p command).
 	:no-default parents:
-	:param exist_ok: If :py:obj:`False` (the default), a :class:`FileExistsError` is raised if the
-		target directory already exists. If :py:obj:`True`, :class:`FileExistsError` exceptions
-		will be ignored (same behavior as the POSIX mkdir -p command), but only if the last path
-		component is not an existing non-directory file.
-	:no-default exist_ok:
+
+	.. versionchanged:: 1.6.0  Removed the ``'exist_ok'`` option, since it made no sense in this context.
+
 	"""
 
 	if not isinstance(directory, pathlib.Path):
 		directory = pathlib.Path(directory)
 
-	if not directory.exists():
-		directory.mkdir(mode, parents, exist_ok)
+	try:
+		directory.mkdir(mode, parents, exist_ok=True)
+	except FileExistsError:
+		pass
 
 
 def parent_path(path: PathLike) -> pathlib.Path:
@@ -358,14 +362,13 @@ class PathPlus(pathlib.Path):
 		.. versionadded:: 0.3.8
 		"""
 
-		with self.open("w", encoding=encoding, errors=errors) as fp:
+		with self.open('w', encoding=encoding, errors=errors) as fp:
 			clean_writer(string, fp)
 
 	def maybe_make(
 			self,
 			mode: int = 0o777,
 			parents: bool = False,
-			exist_ok: bool = False,
 			):
 		"""
 		Create a directory at this path, but only if the directory does not already exist.
@@ -380,18 +383,18 @@ class PathPlus(pathlib.Path):
 			If :py:obj:`True`, any missing parents of this path are created as needed; they are created with the
 			default permissions without taking mode into account (mimicking the POSIX mkdir -p command).
 		:no-default parents:
-		:param exist_ok: If :py:obj:`False` (the default), a :class:`FileExistsError` is raised if the
-			target directory already exists. If :py:obj:`True`, :class:`FileExistsError` exceptions
-			will be ignored (same behavior as the POSIX mkdir -p command), but only if the last path
-			component is not an existing non-directory file.
-		:no-default exist_ok:
 
 		:rtype:
 
 		.. versionadded:: 0.3.8
+
+		.. versionchanged:: 1.6.0  Removed the ``'exist_ok'`` option, since it made no sense in this context.
 		"""
 
-		maybe_make(self, mode=mode, parents=parents, exist_ok=exist_ok)
+		try:
+			self.mkdir(mode, parents, exist_ok=True)
+		except FileExistsError:
+			pass
 
 	def append_text(
 			self,
@@ -411,7 +414,7 @@ class PathPlus(pathlib.Path):
 		.. versionadded:: 0.3.8
 		"""
 
-		with self.open("a", encoding=encoding, errors=errors) as fp:
+		with self.open('a', encoding=encoding, errors=errors) as fp:
 			fp.write(string)
 
 	def write_text(
@@ -450,7 +453,7 @@ class PathPlus(pathlib.Path):
 		.. versionadded:: 0.5.0
 		"""  # noqa D400
 
-		return self.write_clean("\n".join(data), encoding=encoding, errors=errors)
+		return self.write_clean('\n'.join(data), encoding=encoding, errors=errors)
 
 	def read_text(
 			self,
@@ -487,11 +490,11 @@ class PathPlus(pathlib.Path):
 		.. versionadded:: 0.5.0
 		"""  # noqa D400
 
-		return self.read_text(encoding=encoding, errors=errors).split("\n")
+		return self.read_text(encoding=encoding, errors=errors).split('\n')
 
 	def open(  # type: ignore  # noqa A003
 		self,
-		mode: str = "r",
+		mode: str = 'r',
 		buffering: int = -1,
 		encoding: Optional[str] = "UTF-8",
 		errors: Optional[str] = None,
@@ -524,7 +527,7 @@ class PathPlus(pathlib.Path):
 			if 'r' in mode:
 				newline = None
 			else:
-				newline = "\n"
+				newline = '\n'
 
 		return super().open(
 				mode,
@@ -769,3 +772,28 @@ class WindowsPathPlus(PathPlus, pathlib.PureWindowsPath):
 		"""
 
 		raise NotImplementedError("Path.is_mount() is unsupported on this system")
+
+
+def traverse_to_file(base_directory: _P, *filename: PathLike, height: int = -1) -> _P:
+	r"""
+	Traverse the parents of the given directory until the desired file is found.
+
+	:param base_directory: The directory to start searching from
+	:param \*filename: The filename(s) to search for
+	:param height: The maximum height to traverse to.
+
+	.. versionadded:: 1.6.0
+	"""
+
+	if not filename:
+		raise TypeError("traverse_to_file expected 2 or more arguments, got 1")
+
+	for level, directory in enumerate((base_directory, *base_directory.parents)):
+		if height > 0 and ((level - 1) > height):
+			break
+
+		for file in filename:
+			if (directory / file).is_file():
+				return directory
+
+	raise FileNotFoundError(f"'{filename[0]!s}' not found in {base_directory}")
